{% extends "base.html" %}

{% block title %}OT Redirect{% endblock %}

{% block page_content %}
    <style>
        .link-danger {
            font-size: 1.5rem;
        }
    </style>
    {% if data["status"] %}
        <div class="display-6">Click the link below to redirect. Make sure the source is trustworthy.</div>
        <hr>
        <a class="link-danger text-decoration-none" href="{{ data["link"] }}" target="_self">{{ data["link"] }}</a>
    {% else %}
        <div class="display-4">Invalid link!</div>
        <hr>
        <a class="display-6 text-decoration-none" href="/" target="_self">Back to homepage</a>
    {% endif %}
{% endblock %}
