{% extends "base.html" %}

{% block title %}Internal Server Error{% endblock %}

{% block page_content %}
    <div class="page-header">
        <h1>Internal Server Error</h1>
    </div>
{% endblock %}

