/*可以在这里添加你自己的css*/
body {
    font-size: 18px;
}
img {
    max-width: 384px;
    max-height: 384px;
}
iframe {
    max-width: 30vw;
    max-height: 30vh;
}
.OT_reply {
    padding: 0 5px;
    color: black;
    text-decoration: none;
    border: 1px solid black;
    border-radius: 20px;
    background-color: #c1fce3;
    cursor: not-allowed;
    font-size: 16px;
}
.OT_reply:hover {
    color: #444444;
    background-color: #98fcd1;
}